/*
 * 	MSP430G2231 USI SPI Example
 *
 *	Eng: This code is an simple SPI-master example for MSP430G2231 MCU.
 *		 Chip is connected as shown below and the communication starts with
 *		 CS-signal going low (0-active). Master sends one command, which
 *		 tells the slave to turn on the red LED on launchpad (LED1).
 *
 * 	Fin: Yksinkertainen SPI-vyln esimerkkikoodi. Lue tarkemmat tiedot alla
 * 		 olevasta linkist.
 *
 *		MASTER (this code)			   SLAVE
 * 	 	 ______                        ______
 * 		|  P1.5|--------- SCLK -------|P1.5  |
 * 		|  P1.6|--------- MOSI -------|P1.7  |
 * 		|  P1.7|--------  MISO -------|P1.6	 |
 *	    |  P1.4|--------  CS# ------- |P1.4  |
 *	 	|	   |					  |	 P1.0|---LED--RRR-.
 *	 	|______|					  |______|       	  |
 *														 GND												 GND
 *
 * 	Tarkemmat tiedot:
 * 	http://www.hutasu.net/Mikrokontrollerit/MCU_launchpad_osa27.htm
 *
 * 	Flash/RAM = 1116 / 6 bytes
 *
 **/
#include <msp430g2231.h>

#include "Launchpad/launchpad.h"
#include "Launchpad/UART.h"
#include "USI/USI.h"

#include <stdio.h>
#include <string.h>

int main(void)
{
	unsigned char receiveBuffer[10] = {0};
	unsigned char wait = 1;

    WDTCTL = WDTPW | WDTHOLD;	// Stop watchdog timer

    // Init launchpad LEDS and S2
    InitLaunchpad();

    // Init timer for uart and delay
    TimerA_UART_pinInit();
    TimerA_UART_init();

    // Init USI for SPI Master
    InitUSI();
    while(1)
	{
    	// Tell user that we are ready
    	TimerA_UART_print("Master Ready!\r\n\0");
    	if(SWITCH_PRESSED)
    	{
    		// Print command to uart and send it over SPI
			TimerA_UART_print("Set LED1 on\n\r\0");
			SPI_Write((unsigned char *)"LED1=ON!\0");
			__delay_cycles(50);			// wait for slave
			// Read bytes until ending character is received ('!')
			SPI_Read(receiveBuffer);
			if( strcmp("OK!",(const char *)receiveBuffer) == 0)
			{
				// Command succeeded
				TimerA_UART_print("Command OK!\n\r\0");
				// wait only one second
				wait = 1;
				// turn off error led
				LED_RED_OFF;
			}
			else
			{
				// Set error led
				LED_RED_ON;
				// print received data into serial port
				TimerA_UART_print((char *) &receiveBuffer[0]);
				TimerA_UART_print("\n\rError\n\r\0");
				// wait a bit longer after error
				wait = 3;
			}
			// Clear RX buffer
			memset((void*) receiveBuffer, 0, sizeof(receiveBuffer));
    	}
		TimerA_Delay(wait);					// Sleep one second
	}

}
